import * as log from './log'


function tokenHeaders(headers) {
  return {
    'Content-Type': 'application/json',
    Authorization: `Bearer ${localStorage.getItem('token')}`,
    ...headers
  }
}

export class Client {
  login(username, password) {
    // ToDo: handle error
    return fetch("/api/login", {
      method: 'POST',
      headers: { 'Content-Type': 'application/json' },
      body: JSON.stringify({ username, password })
    }).then(r => {
      if (r.status === 200) {
        return r.text()
      }
      log.error(`Got invalid response when trying to login. Code ${r.status}`)
      throw new Error(`${r.status} invalid response`)
    }).then(token => {
      localStorage.setItem('token', token)
      return token
    })
  }

  listGames() {
    return fetch("/api/games", {
      method: 'GET',
      headers: tokenHeaders(),
    }).then(r => {
      if (r.status === 200) {
        return r.json()
      }
      log.error(`Got invalid response when trying to list games. Code ${r.status}`)
      throw new Error(`${r.status} invalid response`)
    })
  }

  getGame(id) {
    return fetch(`/api/games/${id}`, {
      method: 'GET',
      headers: tokenHeaders(),
    }).then(r => {
      if (r.status === 200) {
        return r.json()
      }
      log.error(`Got invalid response when trying to get game ${id}. Code ${r.status}`)
      throw new Error(`${r.status} invalid response`)
    })
  }

  createPostForGame(gameId, message) {
    return fetch(`/api/games/${gameId}/post`, {
      method: 'POST',
      headers: tokenHeaders(),
      body: JSON.stringify({ message })
    }).then(r => {
      if (r.status === 201) {
        return r.json()
      }
      log.error(`Got invalid response when trying to create a post for game ${id}`)
      throw new Error(`${r.status} invalid response`)
    })
  }
}

const client = new Client()
export default client
