import { useState, useContext } from 'react'
import ReactDOM from 'react-dom'
import {
  BrowserRouter as Router,
  Switch,
  Redirect,
  Route,
  Link
} from 'react-router-dom'

import { CssBaseline } from '@material-ui/core';

import { TokenContext } from './context'
import Login from './pages/login'
import Home from './pages/home'
import Game from './pages/game'
import Chat from './pages/chat'


const Secure = ({children}) => {
  const { token } = useContext(TokenContext)
  if (!token) {
    return <Redirect to="/login" />
  }

  return children
}

const App = () => {
  const [token, setToken] = useState(localStorage.getItem('token'))

  return (
    <Router>
      <CssBaseline />
      <Switch>
        <TokenContext.Provider value={{ token, setToken }}>
          <Route exact path="/login">
            <Login />
          </Route>

          <Route exact path="/game/:gameId/chat">
            <Secure>
              <Chat />
            </Secure>
          </Route>

          <Route exact path="/game/:gameId">
            <Secure>
              <Game />
            </Secure>
          </Route>

          <Route exact path="/">
            <Secure>
              <Home />
            </Secure>
          </Route>
        </TokenContext.Provider>
      </Switch>
    </Router>
  )
}

ReactDOM.render(<App />, document.getElementById('app'))
