import { useState, useEffect } from 'react'
import { useParams } from 'react-router-dom'
import {
  Box,
  TextField,
  Button
} from '@material-ui/core';
import * as log from '../log'

import client from '../client'


const Chat = () => {
  const [posts, setPosts] = useState([])
  const [game, setGame] = useState({})
  const [message, setMessage] = useState("")
  const { gameId } = useParams()

  useEffect(() => {
    client.getGame(gameId).then(game => setGame(game))
  }, [gameId])

  const handleChange = (e) => {
    setMessage(e.target.value)
  }

  const handleSubmit = (e) => {
    e.preventDefault()

    client
      .createPostForGame(gameId, message)
      .then(r => {
        log.debug(`Message posted`)
      })

    // maybe disable sending and show a spinner instead
    setMessage("")
  }

  return (
    <div className="game-chat">
      <h1>{game.name}</h1>
      <h2>Chat</h2>

      <form onSubmit={handleSubmit}>
        <input
          id="message"
          type="text"
          name="message"
          placeholder="Message..."
          value={message}
          onChange={handleChange}
        />
        <Button
          type="submit"
          variant="contained"
          color="primary"
          onClick={handleSubmit}
        >Send</Button>
      </form>
    </div>
  )
}

export default Chat
