import {
  useContext,
  useEffect,
  useState
} from 'react'
import { Link } from 'react-router-dom'
import {
  Box,
  Button
} from '@material-ui/core';

import { TokenContext } from '../context'
import client from '../client'


const GameList = () => {
  const [games, setGames] = useState([])

  useEffect(() => {
    client.listGames().then(gameList => setGames(gameList))
  }, [])

  return (
    <div class="game-list">
      <h3 class="game-list-title">Game List</h3>

      <ul>
        {games.map(game => (<li><Link to={`/game/${game.id}`}>{game.name}</Link></li>))}
      </ul>
    </div>
  )
}

const Home = () => {
  const { token, setToken } = useContext(TokenContext)

  const handleLogout = (e) => {
    e.preventDefault()
    localStorage.removeItem('token')
    setToken(null)
  }

  return (
    <Box>
      <h1>Home</h1>

      <GameList />

      <Button
        variant="contained"
        color="secondary"
        onClick={handleLogout}>
        Logout
      </Button>
    </Box>
  )
}

export default Home
