import { useState, useContext } from 'react'
import { Redirect } from 'react-router-dom'
import {
  Box,
  TextField,
  Button
} from '@material-ui/core';

import client from '../client'
import { TokenContext } from '../context'

const Login = () => {
  const { token, setToken } = useContext(TokenContext)

  if (token) {
    return <Redirect to='/' />
  }

  const [username, setUsername] = useState("")
  const [password, setPassword] = useState("")
  const [error, setError] = useState("")

  const handleSubmit = (e) => {
    e.preventDefault()
    client.login(username, password)
      .then(token => {
        setToken(token)
      })
      .catch(e => {
        setError(e.toString())
      })
  }

  const handleChange = (setFn) => {
    return (e) => {
      setFn(e.target.value)
    }
  }

  return (
    <Box>
      <h1>Login</h1>

      <TextField
        id="username"
        label="Username"
        variant="outlined"
        value={username}
        onChange={handleChange(setUsername)}
      />
      <TextField
        id="password"
        label="Password"
        type="password"
        variant="outlined"
        value={password}
        onChange={handleChange(setPassword)}
      />

      {error !== "" && <p style={{color: 'red'}}>{error}</p>}

      <Button variant="contained" color="primary" onClick={handleSubmit}>Login</Button>
    </Box>
  )
}

export default Login
